/*
    bsp_rgb_driver.c

-----------------------------------------------------------------------------

  This file is part of mikroSDK.

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

#include "hal.h"
#include "bsp_rgb_driver.h"

#if ( _MMB_MODULE_RGBLED == 1 )

/* ------------------------------------------------------------------- MACROS */

#if ( defined( _MIKROMEDIA_7_ ) ) || ( ( defined( _MIKROMEDIA_5_ ) || defined( _MIKROMEDIA_4_ ) ) && defined( __KINETIS__ ) )

#   define RGB_I2C_ADDRESS                      0x39

#   define RGB_OUTPUT_POWER                     0x20

#   define RGB_RED_CMD                          0x40
#   define RGB_GREEN_CMD                        0x60
#   define RGB_BLUE_CMD                         0x80

#endif

/* ---------------------------------------------------------------- VARIABLES */


/* --------------------------------------------- EXTERN FUNCTION DECLARATIONS */


/* -------------------------------------------- PRIVATE FUNCTION DECLARATIONS */


/* --------------------------------------------- PRIVATE FUNCTION DEFINITIONS */


/* ----------------------------------------------------------- IMPLEMENTATION */

void bsp_rgb_init ( void )
{
#if ( defined( _MIKROMEDIA_7_ ) ) || ( ( defined( _MIKROMEDIA_5_ ) || defined( _MIKROMEDIA_4_ ) ) && defined( __KINETIS__ ) )

    //  Use standard I2C to communication with module.

    hal_i2c_map( &BSP_RGB_I2C_MODULE );

#endif

    hal_rgb_init( );
    bsp_rgb_set_power( 0x1F );
}

void bsp_rgb_set_power ( uint8_t pwr )
{
#if ( defined( _MIKROMEDIA_7_ ) ) || ( ( defined( _MIKROMEDIA_5_ ) || defined( _MIKROMEDIA_4_ ) ) && defined( __KINETIS__ ) )

    uint8_t tmp;

    tmp = RGB_OUTPUT_POWER | ( pwr & 0x1F );

    //  Use standard I2C to communication with module.

    hal_i2c_start( );
    hal_i2c_write( RGB_I2C_ADDRESS, &tmp, 1, END_MODE_STOP );

#endif
}

void bsp_rgb_clear ( void )
{
#if ( defined( _MIKROMEDIA_7_ ) ) || ( ( defined( _MIKROMEDIA_5_ ) || defined( _MIKROMEDIA_4_ ) ) && defined( __KINETIS__ ) )

    uint8_t tmp;

    tmp = RGB_RED_CMD;

//      Use standard I2C to communication with module.

    hal_i2c_start( );
    hal_i2c_write( RGB_I2C_ADDRESS, &tmp, 1, END_MODE_STOP );

    tmp = RGB_GREEN_CMD;

//      Use standard I2C to communication with module.

    hal_i2c_start( );
    hal_i2c_write( RGB_I2C_ADDRESS, &tmp, 1, END_MODE_STOP );

    tmp = RGB_BLUE_CMD;

//      Use standard I2C to communication with module.

    hal_i2c_start( );
    hal_i2c_write( RGB_I2C_ADDRESS, &tmp, 1, END_MODE_STOP );

#else

    /*
        Use GPIO pins to change RGB colors - optionally PWM module on each pin
        can be used.
    */

    BSP_RGB_RED = 0;
    BSP_RGB_GREEN = 0;
    BSP_RGB_BLUE = 0;

#endif
}

void bsp_rgb_set_red ( uint8_t red )
{
#if ( defined( _MIKROMEDIA_7_ ) ) || ( ( defined( _MIKROMEDIA_5_ ) || defined( _MIKROMEDIA_4_ ) ) && defined( __KINETIS__ ) )

    uint8_t tmp;

    tmp = RGB_RED_CMD | ( red & 0x1F );

//      Use standard I2C to communication with module.

    hal_i2c_start( );
    hal_i2c_write( RGB_I2C_ADDRESS, &tmp, 1, END_MODE_STOP );

#else

    /*
        Use GPIO pins to change RGB colors - optionally PWM module on each pin
        can be used.
    */

    if ( red )
    {
        BSP_RGB_RED = 1;
    }
    else
    {
        BSP_RGB_RED = 0;
    }

#endif
}

void bsp_rgb_set_green ( uint8_t green )
{
#if ( defined( _MIKROMEDIA_7_ ) ) || ( ( defined( _MIKROMEDIA_5_ ) || defined( _MIKROMEDIA_4_ ) ) && defined( __KINETIS__ ) )

    uint8_t tmp;

    tmp = RGB_GREEN_CMD | ( green & 0x1F );

//      Use standard I2C to communication with module.

    hal_i2c_start( );
    hal_i2c_write( RGB_I2C_ADDRESS, &tmp, 1, END_MODE_STOP );

#else

    /*
        Use GPIO pins to change RGB colors - optionally PWM module on each pin
        can be used.
    */

    if ( green )
    {
        BSP_RGB_GREEN = 1;
    }
    else
    {
        BSP_RGB_GREEN = 0;
    }

#endif
}

void bsp_rgb_set_blue ( uint8_t blue )
{
#if ( defined( _MIKROMEDIA_7_ ) ) || ( ( defined( _MIKROMEDIA_5_ ) || defined( _MIKROMEDIA_4_ ) ) && defined( __KINETIS__ ) )

    uint8_t tmp;

    tmp = RGB_BLUE_CMD | ( blue & 0x1F );

    //  Use standard I2C to communication with module.

    hal_i2c_start( );
    hal_i2c_write( RGB_I2C_ADDRESS, &tmp, 1, END_MODE_STOP );

#else

    /*
        Use GPIO pins to change RGB colors - optionally PWM module on each pin
        can be used.
    */

    if ( blue )
    {
        BSP_RGB_BLUE = 1;
    }
    else
    {
        BSP_RGB_BLUE = 0;
    }

#endif
}

void bsp_rgb_set_color ( uint16_t color )
{
#if ( defined( _MIKROMEDIA_7_ ) ) || ( ( defined( _MIKROMEDIA_5_ ) || defined( _MIKROMEDIA_4_ ) ) && defined( __KINETIS__ ) )

    uint8_t tmp[3];

    tmp[0] = RGB_RED_CMD   | ( color & 0x1F );
    tmp[1] = RGB_GREEN_CMD | ( ( color  >> 6  ) & 0x1F );
    tmp[2] = RGB_BLUE_CMD  | ( ( color  >> 11 ) & 0x1F );

    //  Use standard I2C to communication with module.

    hal_i2c_start( );
    hal_i2c_write( RGB_I2C_ADDRESS, tmp, 3, END_MODE_STOP );

#else

    /*
        Use GPIO pins to change RGB colors - optionally PWM module on each pin
        can be used.
    */

    if ( color & 0x1F )
    {
        BSP_RGB_RED = 1;
    }
    else
    {
        BSP_RGB_RED = 0;
    }

    if ( ( color  >> 5 ) & 0x3F )
    {
        BSP_RGB_GREEN = 1;
    }
    else
    {
        BSP_RGB_GREEN = 0;
    }

    if ( ( color  >> 11 ) & 0x1F )
    {
        BSP_RGB_BLUE = 1;
    }
    else
    {
        BSP_RGB_BLUE = 0;
    }

#endif
}

#endif

/* -------------------------------------------------------------------------- */
/*
    bsp_rgb_driver.c

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */