/*
    mmb_---.h

-----------------------------------------------------------------------------

  This file is part of mikroSDK.
  
  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

/**
        \file   mmb_---.h

- Version               :   1.0.0
- Date                  :   May 2019
- Developer             :   Milos Vidojevic

    Generated from mmb---.h template.

    ---

    Template for definition of MCU connections used on mikromedia systems. This 
    file should be used as start point for board definition file development. 

    Hints :

    - Copy file inside [project base directory]/portable.
    - Replace all "---" appearances with proper values.

*/
/* -------------------------------------------------------------------------- */

#include "compiler.h"

#ifndef _MMB_7_---_
#define _MMB_7_---_

/*
    REF SEL jumper position :

    3V3         - 1
    2.048V      - 0
*/

#define JP_VREF                     0

/*
    MP3 jumper position :

    LIN         - 1
    MIC         - 0
*/

#define JP_MP3                      0

/*
    ACCEL jumpers position.
*/

#define JP_ACCEL_A                  0
#define JP_ACCEL_B                  0

/*
    TFT jumpers position.
*/

#define JP_TFT_LR                   1
#define JP_TFT_UD                   0
#define JP_TFT_DITH                 1
#define JP_TFT_MODE                 0

// ============================================================================
//                                                                    DISPLAY
// ============================================================================

extern sfr sbit TFT_BLED;
extern sfr sbit TFT_CS;
extern sfr sbit TFT_RD;
extern sfr sbit TFT_RS;
extern sfr sbit TFT_RST;
extern sfr sbit TFT_WR;

static void hal_display_init ( void )
{
    //  Initialize display.

    ---
}

// ============================================================================
//                                                                      TOUCH
// ============================================================================

static uint8_t hal_touch_init ( void )
{
    //  Initialize touch senor.

    ---
}

// ============================================================================
//                                                                    CONSOLE
// ============================================================================

//  Map proper functions used with console.

#define CONSOLE_WRITE_TXT             ---
#define CONSOLE_READY                 ---
#define CONSOLE_READ                  ---

static void hal_console_init ( void )
{
    // Initialize UART used for console.

    ---
}

// ============================================================================
//                                                                      POWER
// ============================================================================

#if ( _MMB_MODULE_POWER == 1 )

//  Detects external power source on TB1 / CN9.

static sbit BSP_DC_STATUS at                ---;

//  Detects charging of the battery.

static sbit BSP_CHARGER_STATUS at           ---;

#if ( JP_VREF == 0 )
#   define BSP_POWER_ADC_VREF               ( 2.048f )
#elif ( JP_VREF == 1 )
#   define BSP_POWER_ADC_VREF               ( 3.300f )
#else
#   error "REF SEL POSITION UNKNOWN"
#endif

#define BSP_POWER_ADC_CHANNEL               ( --- )
#define BSP_POWER_ADC_RESOLUTION            ( --- )

const static hal_adc_obj_t BSP_POWER_ADC_MODULE =
{
    ---
};

static void hal_power_init ( void )
{
    //  Initialize BSP_DC_STATUS as input pin.

    ---

    //  Initialize BSP_CHARGER_STATUS as input pin.

    ---

    //  Initialize ADC module.
        
    ---
}

#endif

// ============================================================================
//                                                                    MICROSD
// ============================================================================

#if ( _MMB_MODULE_MICROSD == 1 )

//  Navigate to gpio.c file and update sbit variables Mmc_Chip_Select.

const static hal_spi_obj_t BSP_MICROSD_SPI_MODULE =
{
    ---,    //  SPI Write
    ---     //  SPI Read
};

static void hal_microsd_init ( void )
{
    //  Initialize Mmc_Chip_Select as output pin.
        
    ---
    
    //  Initialize SPI module.
    
    ---
}

#endif

// ============================================================================
//                                                                      FLASH
// ============================================================================

#if ( _MMB_MODULE_FLASH == 1 )

static sbit BSP_FLASH_CE at                 ---;

const static hal_spi_obj_t BSP_FLASH_SPI_MODULE =
{
    ---,
    ---
};

static void hal_flash_init ( void )
{
    //  Initialize BSP_FLASH_CE as output pin.
    
    ---

    //  Initialize SPI module.
    
    ---

    BSP_FLASH_CE = 1;
}

#endif

// ============================================================================
//                                                                        RGB
// ============================================================================

#if ( _MMB_MODULE_RGBLED == 1 )
#   ifdef _MIKROMEDIA_7_
#       ifdef __STM32__

//  Navigate to gpio.c file and update sbit variables related to Soft I2C.

static void hal_rgb_init ( void )
{
    //  Initialize I2C bitband.
    
    ---

    Delay_ms( 200 );
}

#       else

const static hal_i2c_obj_t BSP_RGB_I2C_MODULE =
{
    ---,
    ---,
    ---
};

static void hal_rgb_init ( void )
{
    //  Initialize I2C module.
    
    ---
}

#   endif
#else

static sbit BSP_RGB_RED        at                  ---;
static sbit BSP_RGB_GREEN      at                  ---;
static sbit BSP_RGB_BLUE       at                  ---;

static void hal_rgb_init ( void )
{
    //  Initialize all GPIO pins for R/G/B as outputs.
    
    ---
}

#endif
#endif

// ============================================================================
//                                                                         IR
// ============================================================================

#if ( _MMB_MODULE_IR == 1 )

static sbit BSP_IR_RX at                            ---;

static void hal_ir_init ( void )
{
    //  Initialize BSP_IR_TX as input pin.

    ---
}

#endif

// ============================================================================
//                                                                         RF
// ============================================================================

#if ( _MMB_MODULE_RF == 1 )

static sbit BSP_RF_CS at                            ---;
static sbit BSP_RF_CE at                            ---;
static sbit BSP_RF_INT at                           ---;

const static hal_spi_obj_t BSP_RF_SPI_MODULE =
{
    ---,
    ---
};

static void hal_rf_init ( void )
{
    //  Initialize BSP_RF_INT as input pin.

    ---

    //  Initialize BSP_RF_CE as output pin.

    ---
    
    //  Initialize BSP_RF_CS as output pin.

    ---
    
    //  Initialize SPI module.
    
    ---

}
#endif

// ============================================================================
//                                                                        MP3
// ============================================================================

#if ( _MMB_MODULE_MP3 == 1 )

static volatile sbit BSP_MP3_DREQ at                 ---;
static volatile sbit BSP_MP3_CS at                   ---;
static volatile sbit BSP_MP3_RST at                  ---;
static volatile sbit BSP_MP3_DCS at                  ---;

static const hal_spi_obj_t BSP_MP3_SPI_MODULE =
{
    ---, 
    ---
};

static void hal_mp3_init ( void )
{
    //  Initialize BSP_MP3_DREQ as input pin.

    ---

    //  Initialize BSP_MP3_CS as output pin.

    ---

    //  Initialize BSP_MP3_RST as output pin.

    ---

    //  Initialize BSP_MP3_DCS as output pin.

    ---

    //  Initialize SPI module.

    ---
}

#endif

// ============================================================================
//                                                                      ACCEL
// ============================================================================

#if ( _MMB_MODULE_ACCEL == 1 )

static sbit BSP_ACCEL_INT_1 at                          ---;
static sbit BSP_ACCEL_INT_2 at                          ---;

const static hal_i2c_obj_t BSP_ACCEL_I2C_MODULE =
{
    ---,
    ---,
    ---
};

static void hal_accel_init ( void )
{
    //  Initialize BSP_ACCEL_INT_1 as input pin.
    
    ---
    
    //  Initialize BSP_ACCEL_INT_2 as input pin.
    
    ---

    //  Initialize I2C module. 

    ---
}

#endif

// ============================================================================
//                                                                        ALS
// ============================================================================

#if ( _MMB_MODULE_ALS == 1 )

const static hal_i2c_obj_t BSP_ALS_I2C_MODULE =
{
    ---, 
    ---,
    ---
};

static void hal_als_init ( void )
{
    //  Initialize I2C module.    

    ---
}

#endif

// ============================================================================
//                                                                       TEMP
// ============================================================================

#if ( _MMB_MODULE_TEMP == 1 )

#if ( JP_VREF == 0 )
#   define BSP_TEMP_ADC_VREF                ( 2.048f )
#elif ( JP_VREF == 1 )
#   define BSP_TEMP_ADC_VREF                ( 3.300f )
#else
#   error "REF SEL POSITION UNKNOWN"
#endif

#define BSP_TEMP_ADC_CHANNEL                ( --- )
#define BSP_TEMP_ADC_RESOLUTION             ( --- )

const static hal_adc_obj_t BSP_TEMP_ADC_MODULE =
{
    ---,
    ---
};

static void hal_temp_init ( void )
{
    // Set analog input to the TEMP Pin

    ---
    
    //  Initialize ADC module.

    ---
}

#endif

// ============================================================================
//                                                                       WIFI
// ============================================================================

#if ( _MMB_MODULE_WIFI == 1 )

static volatile sbit CC3100_HIB_PIN     at          ---;
static volatile sbit CC3100_CS_PIN      at          ---;
static volatile sbit CC3100_RST_PIN     at          ---;

const static hal_spi_obj_t BSP_WIFI_SPI_MODULE =
{
    ---,
    ---
};

static void hal_wifi_init ( void )
{
    //  Disable interrupt for WiFi module.

    ---

    //  Initialize CC3100 HIB as input pin.
    
    ---
    
    //  Initialize CC3100 RST as input pin.
    
    ---
    
    //  Initialize CC3100 CS as input pin.
    
    ---
    
    //  Initialize CC3100 INT as input pin.
    
    ---
    
    /*
        Initialize CC3100 SPI peripheral.

        NOTE : 

            SPI must be configured to SPI mode 0 ( IDLE LOW / FIRST EDGE ).
    */

    ---

    CC3100_CS_PIN = 1;
}

#endif

// ============================================================================
//                                                                     BUZZER
// ============================================================================

#if ( _MMB_MODULE_BUZZER == 1 )

static void hal_buzzer_init ( void )
{
    //  Initialize BUZZER pin as output.

    ---

    //  Initialize Sound library.

    ---
}

#endif

// ============================================================================
//                                                                   ETHERNET
// ============================================================================

#if ( _MMB_MODULE_ETHERNET == 1 )

#include "__Ethernet_Intern.h"

static void hal_ethernet_init ( uint8_t * mac, uint8_t * ip )
{
    // Initialize ETH library.

    
}

#endif

// ============================================================================
//                                                                        RTC
// ============================================================================

#if ( _MMB_MODULE_RTC == 1 )

static void hal_rtc_init ( void )
{
    //  Initialize RTC module.

    ---

}

#endif

// ============================================================================
//                                                                        USB
// ============================================================================

#if ( _MMB_MODULE_USB == 1 )

//  Enables power for USB device.

static sbit BSP_USB_PSW at                          ---;

static void hal_usb_init ( void )
{
    //  Enable alternate GPIO function if needed

    ---

    //  Initialize PWS pin as output.

    ---

    // PSW to 0 to turn on power for device.

    BSP_USB_PSW = 1;
    Delay_ms( 100 );
    BSP_USB_PSW = 0;
}

#endif

// ============================================================================
//                                                                    SHUTTLE
// ============================================================================

#if ( _MMB_MODULE_SHUTTLE == 1 )



#endif
#endif

/* -------------------------------------------------------------------------- */
/*
    mmb_mcu_---.h

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */
