/*
    interrupt.c

-----------------------------------------------------------------------------

  This file is part of mikroSDK.
  
  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

/**
        \file   interrupt.c

- Version               :   1.0.0
- Date                  :   May 2019
- Developer             :   Milos Vidojevic

    Common interrupt module.

    Hints :

    - Copy file inside [project base directory]/portable.
    - Replace all "---" appearances with proper values.

*/
/* -------------------------------------------------------------------------- */

#include "simplelink.h"

#if ( _MMB_MODULE_WIFI == 1 )

/*
    WiFi interrupt related functions and variables.
*/

P_EVENT_HANDLER wifi_isr_event;

void bsp_wifi_driver_interrupt_enable ( void )
{
    //  Enable interrupt vector for CC3100 INT pin.

    NVIC_IntEnable( IVT_INT_GPIOB );         // Enable GPIOB interrupt
}

void bsp_wifi_driver_interrupt_disable ( void )
{
    //  Disable interrupt vector for CC3100 INT pin.

    NVIC_IntDisable( IVT_INT_GPIOB );        // Disable GPIOB interrupt
}

/*
    WiFi ISR Function.
*/

void WIFI_EXT_ISR ( void ) iv IVT_INT_GPIOB ics ICS_AUTO
{
    //  Reset interrupt flag
    
    GPIO_PORTB_AHB_ICR = _GPIO_PINMASK_2;        // clear flag

    if ( wifi_isr_event != ( void * ) 0 )
    {
        ( *wifi_isr_event )( 0 );
    }
}

#endif

/*
    USB interrupt related functions and variables.
*/

#ifdef TEST_PROJECT

    void USB_ISR( ) iv IVT_INT_USB
    {
        USBHost_IntHandler( );
    }

#endif

/*
    Common initialize functions which should initialize all necessary 
    interrupts.
*/

void interrupts_enable ( void )
{
    /*
        Initialize external interrupt on CC3100 INT pin.

        NOTE : 

            Interrupt must be configured to trigger on rising edge.
    */
    
    NVIC_IntDisable( IVT_INT_GPIOB );         // Enable GPIOB interrupt
    DisableInterrupts( );

    GPIO_Digital_Input( &GPIO_PORTB_AHB, _GPIO_PINMASK_2 );

//    GPIO_PORTB_AHB_AFSEL = _GPIO_PINMASK_2;   // Enable alternate pin functions
    GPIO_PORTB_AHB_IS    = 0;                 // Edge sensitive
    GPIO_PORTB_AHB_IBE   = 0;                 // Edge/Level detection triggers interrupt
    GPIO_PORTB_AHB_IEV   = _GPIO_PINMASK_2;   // Rising Edge will trigger interrupt
    GPIO_PORTB_AHB_IM    = _GPIO_PINMASK_2;   // Set mask to pin2
    NVIC_IntEnable( IVT_INT_GPIOB );          // Enable GPIOB interrupt

    /*
        Initialize global interrupts and enable vectors.

            - Enable interrupt vector for USB.
            - Enable interrupt vector for CC3100 INT pin.
    */

    #ifdef TEST_PROJECT

        NVIC_IntEnable( IVT_INT_USB );
    
    #endif

    NVIC_IntEnable( IVT_INT_GPIOB );         // Enable GPIOM interrupt
    EnableInterrupts( );
}