/*
    mmb_---.h

-----------------------------------------------------------------------------

  This file is part of mikroSDK.
  
  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

/**
        \file   mmb_---.h

- Version               :   1.0.0
- Date                  :   May 2019
- Developer             :   Milos Vidojevic

    Generated from mmb---.h template.

    ---

    Template for definition of MCU connections used on mikromedia systems. This 
    file should be used as start point for board definition file development. 

    Hints :

    - Copy file inside [project base directory]/portable.
    - Replace all "---" appearances with proper values.

*/
/* -------------------------------------------------------------------------- */

#include "compiler.h"

#ifndef _MMB_5_TM4CXNCZAD_
#define _MMB_5_TM4CXNCZAD_

/*
    REF SEL jumper position :

    3V3         - 1
    2.048V      - 0
*/

#define JP_VREF                     0

/*
    MP3 jumper position :

    LIN         - 1
    MIC         - 0
*/

#define JP_MP3                      1

/*
    ACCEL jumpers position.
*/

#define JP_ACCEL_A                  0
#define JP_ACCEL_B                  0

/*
    TFT jumpers position.
*/

#define JP_TFT_LR                   1
#define JP_TFT_UD                   0
#define JP_TFT_DITH                 1
#define JP_TFT_MODE                 0

#define SPI0_SPEED                  3000000
#define SPI1_SPEED                  5000000

typedef struct {
  unsigned long  config;
  unsigned int   displayWidth;
  unsigned int   displayHeight;
  unsigned int   horizontalFrontPorch;
  unsigned int   horizontalBackPorch;
  unsigned int   horizontalSyncWidth;
  unsigned short verticalFrontPorch;
  unsigned short verticalBackPorch;
  unsigned short verticalSyncWidth;
  unsigned short biasLineCount;
} TLCDRasterTiming;

// ============================================================================
//                                                                    DISPLAY
// ============================================================================

/*extern sfr sbit TFT_16bit_BLED;
extern sfr sbit TFT_16bit_CS;
extern sfr char TFT_16bit_DataPort_Hi;
extern sfr char TFT_16bit_DataPort_Lo;
extern sfr sbit TFT_16bit_RD;
extern sfr sbit TFT_16bit_RS;
extern sfr sbit TFT_16bit_RST;
extern sfr sbit TFT_16bit_WR;
extern sfr sbit TFT_16bit_BLED_Direction;
extern sfr sbit TFT_16bit_CS_Direction;
extern sfr char TFT_16bit_DataPort_Hi_Direction;
extern sfr char TFT_16bit_DataPort_Lo_Direction;
extern sfr sbit TFT_16bit_RD_Direction;
extern sfr sbit TFT_16bit_RS_Direction;
extern sfr sbit TFT_16bit_RST_Direction;
extern sfr sbit TFT_16bit_WR_Direction;*//*static void Write_to_Data_Lines( unsigned char _hi, unsigned char _lo )
{
    TFT_16bit_DataPort_Lo = (unsigned int) _lo;
    TFT_16bit_DataPort_Hi = (unsigned int) _hi;
}

static void Set_Index( unsigned short index )
{
    TFT_16bit_RS = 0;
    Write_to_Data_Lines(0, index);
    TFT_16bit_WR = 0;
    asm nop;
    TFT_16bit_WR = 1;
}

static void Write_Command( unsigned short cmd )
{
    TFT_16bit_RS = 1;
    Write_to_Data_Lines( 0, cmd );
    TFT_16bit_WR = 0;
    asm nop;
    TFT_16bit_WR = 1;
}

static void Write_Data( unsigned int _data )
{
    TFT_16bit_RS = 1;
//    Write_to_Data_Lines( Hi(_data), Lo(_data) );
    Write_to_Data_Lines( ( _data >> 8 ), ( _data & 0x00FF ) );
    TFT_16bit_WR = 0;
    asm nop;
    TFT_16bit_WR = 1;
}*/

static void hal_display_init ( void )
{
TLCDRasterTiming Timings;

//      Initialize display.

  GPIO_Digital_Output(&GPIO_PORTM, _GPIO_PINMASK_6);
  GPIO_PORTM_DATA.B6 = 1;
  SPI1_Init_Advanced(15000000, _SPI_MASTER, _SPI_8_BIT | _SPI_CLK_IDLE_LOW | _SPI_FIRST_CLK_EDGE_TRANSITION, &_GPIO_MODULE_SPI1_B5E45_AHB);
  uDMA_Init();
  EPI_SDRAM_Init();
  TFTIntern_SetDefaultMode();
  TFTIntern_SetDisplayRotation(_TFT_INTERN_ROTATE_180);

  GPIO_Alternate_Function_Enable(&_GPIO_MODULE_LCD_RASTER_24BPP);
  SYSCTL_RCGCLCD = 0x01;
  TFTIntern_ModeSet(_TFT_INTERN_MODE_RASTER | _TFT_INTERN_MODE_AUTO_UFLOW_RESTART, 40000000, 120000000);
  TFTIntern_RasterConfigSet(_RASTER_FMT_ACTIVE_PALETTIZED_16BIT | _RASTER_LOAD_DATA_ONLY, 0);
  Timings.config =  _RASTER_TIMING_SYNCS_ON_RISING_PIXCLK | _RASTER_TIMING_ACTIVE_HIGH_OE | _RASTER_TIMING_ACTIVE_HIGH_PIXCLK | _RASTER_TIMING_ACTIVE_HIGH_HSYNC | _RASTER_TIMING_ACTIVE_HIGH_VSYNC;
  Timings.displayWidth  = 800;
  Timings.displayHeight = 480;
  Timings.horizontalFrontPorch = 40;
  Timings.horizontalBackPorch  = 40;
  Timings.horizontalSyncWidth  = 48;
  Timings.verticalFrontPorch   = 13;
  Timings.verticalBackPorch    = 29;
  Timings.verticalSyncWidth    = 3;
  Timings.biasLineCount        = 0;
  TFTIntern_RasterTimingSet(&Timings);
  TFTIntern_SetDisplaySize(800, 480);
  TFTIntern_DMAConfigSet(_TFT_INTERN_DMA_PRIORITY_7 | _TFT_INTERN_DMA_FIFORDY_512_WORDS | _TFT_INTERN_DMA_BURST_16 | _TFT_INTERN_DMA_BYTE_ORDER_0123 | _TFT_INTERN_DMA_PING_PONG);
  TFTIntern_RasterFrameBufferSet(0, (unsigned long *)(0x10000000+0x0),768000);
  TFTIntern_RasterFrameBufferSet(1, (unsigned long *)(0x10000000+0x0),768000);
  TFTIntern_RasterPaletteSet(_TFT_INTERN_PALETTE_TYPE_DIRECT, (unsigned long *)(0x10000000), 0, 0, 0);
  TFTIntern_SetMemoryStartAddr((unsigned int *)(0x10000000));
  TFTIntern_RasterEnable();
}

// ============================================================================
//                                                                      TOUCH
// ============================================================================

static uint8_t hal_touch_init ( void )
{
    //  Initialize touch senor.

    I2C2_Init_Advanced( _I2C_BITRATE_FAST_MODE, &_GPIO_MODULE_I2C2_P56 );
    
    Delay_100ms( );
    Delay_100ms( );
    Delay_100ms( );

//    TFTIntern_Set_Default_Mode( );
    
    FT5XX6_SetI2CAddress(0x38);
    
    if (FT5XX6_IsOperational( ) != FT5XX6_OK)
    {
        return  FT5XX6_FAILURE;
    }
    FT5XX6_SetDefaultMode( );
    FT5XX6_SetController( _TC_FT5X06 );
    FT5XX6_SetSizeAndRotation( 800, 480, 2 );
    
    return FT5XX6_OK;
}

// ============================================================================
//                                                                    CONSOLE
// ============================================================================

//  Map proper functions used with console.

#define CONSOLE_WRITE_TXT             UART3_Write_Text
#define CONSOLE_READY                 UART3_Data_Ready
#define CONSOLE_READ                  UART3_Read

static void hal_console_init ( void )
{
    // Initialize UART used for console.

    UART3_Init_Advanced( 115200, 120000, _UART_8_BIT_DATA, _UART_NOPARITY, _UART_ONE_STOPBIT, _UART_HIGH_SPEED, &_GPIO_MODULE_UART3_J01_AHB );
    
    Delay_100ms( );
}

// ============================================================================
//                                                                      POWER
// ============================================================================

#if ( _MMB_MODULE_POWER == 1 )

//  Detects external power source on TB1 / CN9.

static sbit BSP_DC_STATUS at                GPIO_PORTN_DATA.B5;

//static sbit BSP_DC_STATUS at                GPIO_PORTN_DATA5_bit;

//  Detects charging of the battery.

static sbit BSP_CHARGER_STATUS at           GPIO_PORTN_DATA.B4;

//static sbit BSP_CHARGER_STATUS at           GPIO_PORTN_DATA4_bit;

#if ( JP_VREF == 0 )
#   define BSP_POWER_ADC_VREF               ( 2.048f )
#elif ( JP_VREF == 1 )
#   define BSP_POWER_ADC_VREF               ( 3.300f )
#else
#   error "REF SEL POSITION UNKNOWN"
#endif

#define BSP_POWER_ADC_CHANNEL               ( 19 )
#define BSP_POWER_ADC_RESOLUTION            ( 4095f )

const static hal_adc_obj_t BSP_POWER_ADC_MODULE =
{
    ADC0_Read,
    ADC0_Get_Sample
};

static void hal_power_init ( void )
{
    //  Initialize BSP_DC_STATUS as input pin.

    GPIO_Digital_Input( &GPIO_PORTN_DATA, _GPIO_PINMASK_5 );

    //  Initialize BSP_CHARGER_STATUS as input pin.

    GPIO_Digital_Input( &GPIO_PORTN_DATA, _GPIO_PINMASK_4 );
    
    // Set analog input to the POWER Pin

    GPIO_Analog_Input( &GPIO_PORTK_DATA, _GPIO_PINMASK_3 );

    //  Initialize ADC module.

    GPIO_Alternate_Function_Enable( &_GPIO_MODULE_AIN19 );

    ADC_Set_Input_Channel( _ADC_CHANNEL_19 );
    
    ADC0_Init( );
    
    Delay_100ms( );
    Delay_100ms( );
    Delay_100ms( );
}

#endif

// ============================================================================
//                                                                    MICROSD
// ============================================================================

#if ( _MMB_MODULE_MICROSD == 1 )

//  Navigate to gpio.c file and update sbit variables Mmc_Chip_Select.

const static hal_spi_obj_t BSP_MICROSD_SPI_MODULE =
{
    SPI0_Write,
    SPI0_Read
};

static void hal_microsd_init ( void )
{
    //  Initialize Mmc_Chip_Select as output pin.
    
    GPIO_Digital_Output( &GPIO_PORTA_AHB_DATA, _GPIO_PINMASK_3 );

    //  Initialize SPI module.

    GPIO_Alternate_Function_Enable( &_GPIO_MODULE_SPI0_A245_AHB );
    
    SPI0_Init_Advanced( SPI0_SPEED, _SPI_MASTER, _SPI_8_BIT | _SPI_CLK_IDLE_LOW | _SPI_FIRST_CLK_EDGE_TRANSITION, &_GPIO_MODULE_SPI0_A245_AHB );
    
    Delay_100ms( );
    Delay_100ms( );
    Delay_100ms( );
}

#endif

// ============================================================================
//                                                                      FLASH
// ============================================================================

#if ( _MMB_MODULE_FLASH == 1 )

static sbit BSP_FLASH_CE at                 GPIO_PORTP_DATA.B7;

//static sbit BSP_FLASH_CE at                 GPIO_PORTF_AHB_DATA7_bit;

const static hal_spi_obj_t BSP_FLASH_SPI_MODULE =
{
    SPI0_Write,
    SPI0_Read
};

static void hal_flash_init ( void )
{
    //  Initialize BSP_FLASH_CE as output pin.
    
    GPIO_Digital_Output( &GPIO_PORTP_DATA, _GPIO_PINMASK_7 );

    //  Initialize SPI module.
    
    GPIO_Alternate_Function_Enable( &_GPIO_MODULE_SPI0_A245_AHB );
    
    SPI0_Init_Advanced( SPI0_SPEED, _SPI_MASTER, _SPI_8_BIT | _SPI_CLK_IDLE_LOW | _SPI_FIRST_CLK_EDGE_TRANSITION, &_GPIO_MODULE_SPI0_A245_AHB );
    
    Delay_100ms( );
    Delay_100ms( );
    Delay_100ms( );

    BSP_FLASH_CE = 1;
}

#endif

// ============================================================================
//                                                                        RGB
// ============================================================================

#if ( _MMB_MODULE_RGBLED == 1 )

static sbit BSP_RGB_RED   at                          GPIO_PORTD_AHB_DATA.B2;
static sbit BSP_RGB_GREEN at                          GPIO_PORTD_AHB_DATA.B3;
static sbit BSP_RGB_BLUE  at                          GPIO_PORTD_AHB_DATA.B5;

//static sbit BSP_RGB_RED   at                          GPIO_PORTD_AHB_DATA2_bit;
//static sbit BSP_RGB_GREEN at                          GPIO_PORTD_AHB_DATA3_bit;
//static sbit BSP_RGB_BLUE  at                          GPIO_PORTD_AHB_DATA5_bit;

static void hal_rgb_init ( void )
{
    //  Initialize I2C module.

    // RED LED
    GPIO_Digital_Output( &GPIO_PORTD_AHB_DATA, _GPIO_PINMASK_2 );
    
    // GREEN LED
    GPIO_Digital_Output( &GPIO_PORTD_AHB_DATA, _GPIO_PINMASK_3 );
    
    // BLUE LED
    GPIO_Digital_Output( &GPIO_PORTD_AHB_DATA, _GPIO_PINMASK_5 );
}

#endif

// ============================================================================
//                                                                         IR
// ============================================================================

#if ( _MMB_MODULE_IR == 1 )

static sbit BSP_IR_RX at                            GPIO_PORTD_AHB_DATA.B4;

//static sbit BSP_IR_RX at                            GPIO_PORTD_AHB_DATA4_bit;

static void hal_ir_init ( void )
{
    //  Initialize BSP_IR_TX as input pin.

    GPIO_Digital_Input( &GPIO_PORTD_AHB_DATA, _GPIO_PINMASK_4 );
}

#endif

// ============================================================================
//                                                                         RF
// ============================================================================

#if ( _MMB_MODULE_RF == 1 )

static sbit BSP_RF_CE  at                           GPIO_PORTG_AHB_DATA.B3;
static sbit BSP_RF_CS  at                           GPIO_PORTF_AHB_DATA.B6;
static sbit BSP_RF_INT at                           GPIO_PORTG_AHB_DATA.B2;

//static sbit BSP_RF_CE  at                           GPIO_PORTG_AHB_DATA3_bit;
//static sbit BSP_RF_CS  at                           GPIO_PORTF_AHB_DATA6_bit;
//static sbit BSP_RF_INT at                           GPIO_PORTG_AHB_DATA2_bit;

const static hal_spi_obj_t BSP_RF_SPI_MODULE =
{
    SPI1_Write,
    SPI1_Read
};

static void hal_rf_init ( void )
{
    //  Initialize BSP_RF_CE as output pin.

    GPIO_Digital_Output( &GPIO_PORTG_AHB_DATA, _GPIO_PINMASK_3 );

    //  Initialize BSP_RF_CS as output pin.

    GPIO_Digital_Output( &GPIO_PORTF_AHB_DATA, _GPIO_PINMASK_6 );
    
    //  Initialize BSP_RF_INT as input pin.

    GPIO_Digital_Input( &GPIO_PORTG_AHB_DATA, _GPIO_PINMASK_2 );

    //  Initialize SPI module.
    
    GPIO_Alternate_Function_Enable( &_GPIO_MODULE_SPI1_B5E45_AHB );
    
    SPI1_Init_Advanced( SPI1_SPEED, _SPI_MASTER, _SPI_8_BIT | _SPI_CLK_IDLE_LOW | _SPI_FIRST_CLK_EDGE_TRANSITION, &_GPIO_MODULE_SPI1_B5E45_AHB );
    
    Delay_100ms( );
    Delay_100ms( );
    Delay_100ms( );
    
    SPI_Set_Active( SPI0_Read, SPI0_Write );
}
#endif

// ============================================================================
//                                                                        MP3
// ============================================================================

#if ( _MMB_MODULE_MP3 == 1 )

static volatile sbit BSP_MP3_CS               at            GPIO_PORTN_DATA.B0;
static volatile sbit BSP_MP3_RST              at            GPIO_PORTN_DATA.B2;
static volatile sbit BSP_MP3_DREQ             at            GPIO_PORTN_DATA.B1;
static volatile sbit BSP_MP3_DCS              at            GPIO_PORTN_DATA.B3;

//static volatile sbit BSP_MP3_CS               at            GPIO_PORTN_DATA0_bit;
//static volatile sbit BSP_MP3_RST              at            GPIO_PORTN_DATA2_bit;
//static volatile sbit BSP_MP3_DREQ             at            GPIO_PORTN_DATA1_bit;
//static volatile sbit BSP_MP3_DCS              at            GPIO_PORTN_DATA3_bit;

static const hal_spi_obj_t BSP_MP3_SPI_MODULE =
{
    SPI0_Write,
    SPI0_Read
};

static void hal_mp3_init ( void )
{
    //  Initialize BSP_MP3_CS as output pin.
    
    GPIO_Digital_Output( &GPIO_PORTN, _GPIO_PINMASK_0 );

    //  Initialize BSP_MP3_RST as output pin.

    GPIO_Digital_Output( &GPIO_PORTN, _GPIO_PINMASK_2 );
    
    //  Initialize BSP_MP3_DREQ as input pin.

    GPIO_Digital_Input( &GPIO_PORTN, _GPIO_PINMASK_1 );

    //  Initialize BSP_MP3_DCS as output pin.

    GPIO_Digital_Output( &GPIO_PORTN, _GPIO_PINMASK_3 );

    //  Initialize SPI module.
    
    GPIO_Alternate_Function_Enable( &_GPIO_MODULE_SPI0_A245_AHB );

    SPI0_Init_Advanced( SPI0_SPEED, _SPI_MASTER, _SPI_8_BIT | _SPI_CLK_IDLE_LOW | _SPI_FIRST_CLK_EDGE_TRANSITION, &_GPIO_MODULE_SPI0_A245_AHB );
    
    Delay_100ms( );
    Delay_100ms( );
    Delay_100ms( );
}

#endif

// ============================================================================
//                                                                      ACCEL
// ============================================================================

#if ( _MMB_MODULE_ACCEL == 1 )

static sbit BSP_ACCEL_INT_1 at                          GPIO_PORTK_DATA.B4;
static sbit BSP_ACCEL_INT_2 at                          GPIO_PORTK_DATA.B1;

//static sbit BSP_ACCEL_INT_1 at                          GPIO_PORTK_DATA4_bit;
//static sbit BSP_ACCEL_INT_2 at                          GPIO_PORTK_DATA1_bit;

const static hal_i2c_obj_t BSP_ACCEL_I2C_MODULE =
{
    I2C2_Master_Slave_Addr_Set,
    I2C2_Write,
    I2C2_Read
};

static void hal_accel_init ( void )
{
    //  Initialize BSP_ACCEL_INT_1 as input pin.
    
    GPIO_Digital_Input( &GPIO_PORTK_DATA, _GPIO_PINMASK_4 );
    
    //  Initialize BSP_ACCEL_INT_2 as input pin.
    
    GPIO_Digital_Input( &GPIO_PORTK_DATA, _GPIO_PINMASK_1 );

    //  Initialize I2C module.

    I2C2_Init_Advanced( _I2C_BITRATE_FAST_MODE, &_GPIO_MODULE_I2C2_P56 );
    
    Delay_100ms( );
    Delay_100ms( );
    Delay_100ms( );
    Delay_100ms( );
    Delay_100ms( );
    
    I2C_Set_Active( I2C2_Enable, I2C2_Master_Slave_Addr_Set, I2C2_Write, I2C2_Read, I2C2_Disable );
}

#endif

// ============================================================================
//                                                                        ALS
// ============================================================================

#if ( _MMB_MODULE_ALS == 1 )

const static hal_i2c_obj_t BSP_ALS_I2C_MODULE =
{
    I2C2_Master_Slave_Addr_Set,
    I2C2_Write,
    I2C2_Read
};

static void hal_als_init ( void )
{
    //  Initialize I2C module.    

    I2C2_Init_Advanced( _I2C_BITRATE_FAST_MODE, &_GPIO_MODULE_I2C2_P56 );
    
    Delay_100ms( );
    Delay_100ms( );
    Delay_100ms( );
    Delay_100ms( );
    Delay_100ms( );

    I2C_Set_Active( I2C2_Enable, I2C2_Master_Slave_Addr_Set, I2C2_Write, I2C2_Read, I2C2_Disable );
}

#endif

// ============================================================================
//                                                                       TEMP
// ============================================================================

#if ( _MMB_MODULE_TEMP == 1 )

#if ( JP_VREF == 0 )
    #define BSP_TEMP_ADC_VREF                ( 2.048f )
#elif ( JP_VREF == 1 )
    #define BSP_TEMP_ADC_VREF                ( 3.300f )
#else
    #error "REF SEL POSITION UNKNOWN"
#endif

#define BSP_TEMP_ADC_CHANNEL                ( 18 )
#define BSP_TEMP_ADC_RESOLUTION             ( 4095f )

const static hal_adc_obj_t BSP_TEMP_ADC_MODULE =
{
    ADC0_Read,
    ADC0_Get_Sample
};

static void hal_temp_init ( void )
{
    // Set analog input to the TEMP Pin

    GPIO_Analog_Input( &GPIO_PORTK_DATA, _GPIO_PINMASK_2 );
    
    //  Initialize ADC module.

    GPIO_Alternate_Function_Enable( &_GPIO_MODULE_AIN18 );

    ADC_Set_Input_Channel( _ADC_CHANNEL_18 );
    
    ADC0_Init( );
    
    Delay_100ms( );
    Delay_100ms( );
    Delay_100ms( );
}

#endif

// ============================================================================
//                                                                       WIFI
// ============================================================================

#if ( _MMB_MODULE_WIFI == 1 )

static volatile sbit CC3100_HIB_PIN     at          GPIO_PORTF_AHB_DATA.B5;
static volatile sbit CC3100_RST_PIN     at          GPIO_PORTD_AHB_DATA.B7;
static volatile sbit CC3100_CS_PIN      at          GPIO_PORTB_AHB_DATA.B4;

//static volatile sbit CC3100_HIB_PIN     at          GPIO_PORTF_AHB_DATA5_bit;
//static volatile sbit CC3100_RST_PIN     at          GPIO_PORTD_AHB_DATA7_bit;
//static volatile sbit CC3100_CS_PIN      at          GPIO_PORTB_AHB_DATA4_bit;

const static hal_spi_obj_t BSP_WIFI_SPI_MODULE =
{
    SPI1_Write,
    SPI1_Read
};

static void hal_wifi_init ( void )
{
    //  Disable interrupt for WiFi module.

    NVIC_IntDisable( IVT_INT_GPIOB );        // Disable GPIOB interrupt
    
    //  Initialize CC3100 HIB as input pin.

    GPIO_Digital_Output( &GPIO_PORTF_AHB_DATA, _GPIO_PINMASK_5 );

    //  Initialize CC3100 RST as input pin.

    GPIO_Unlock_AHB( _GPIO_COMMIT_PIN_D7 );
    GPIO_Digital_Output( &GPIO_PORTD_AHB_DATA, _GPIO_PINMASK_7 );

    //  Initialize CC3100 CS as input pin.

    GPIO_Digital_Output( &GPIO_PORTB_AHB_DATA, _GPIO_PINMASK_4 );

    //  Initialize CC3100 INT as input pin.

    GPIO_Digital_Input( &GPIO_PORTB_AHB_DATA, _GPIO_PINMASK_2 );
    
    /*
        Initialize CC3100 SPI peripheral.

        NOTE : 

            SPI must be configured to SPI mode 0 ( IDLE LOW / FIRST EDGE ).
    */
    
    GPIO_Alternate_Function_Enable( &_GPIO_MODULE_SPI1_B5E45_AHB );

    SPI1_Init_Advanced( SPI1_SPEED, _SPI_MASTER, _SPI_8_BIT | _SPI_CLK_IDLE_LOW | _SPI_FIRST_CLK_EDGE_TRANSITION, &_GPIO_MODULE_SPI1_B5E45_AHB );
    
    Delay_100ms( );
    Delay_100ms( );
    Delay_100ms( );
    
    SPI_Set_Active( SPI0_Read, SPI0_Write );

    CC3100_CS_PIN = 1;
}

#endif

// ============================================================================
//                                                                     BUZZER
// ============================================================================

#if ( _MMB_MODULE_BUZZER == 1 )

static void hal_buzzer_init ( void )
{
    //  Initialize BUZZER pin as output.

    GPIO_Digital_Output( &GPIO_PORTM_DATA, _GPIO_PINMASK_7 );

    //  Initialize Sound library.

    Sound_Init( &GPIO_PORTM_DATA, 7 );
    
    Delay_100ms( );
}

#endif

// ============================================================================
//                                                                   ETHERNET
// ============================================================================

#if ( _MMB_MODULE_ETHERNET == 1 )

#include "__ethernet_intern.h"

static void hal_ethernet_init ( uint8_t * mac, uint8_t * ip )
{
    // Initialize ETH library.

    GPIO_Alternate_Function_Enable( &_GPIO_MODULE_ETHLED_F014_AHB );
    
    Ethernet_Intern_Init( mac, ip, _ETHERNET_FULLDUPLEX | _ETHERNET_SPD100 );
}

#endif

// ============================================================================
//                                                                        RTC
// ============================================================================

#if ( _MMB_MODULE_RTC == 1 )

static void hal_rtc_init ( void )
{
    //  Initialize RTC module.

//    if (( HIB_CTL & 0x40 ) != 0x40);
    
    while (!HIB_CTL_WRC_bit);
    HIB_CTL = 0x40;                                  // Enable 32.768kHz osc
    while (!HIB_CTL_WRC_bit);
    HIB_RTCM0 = 86400;                               // 24 hour equivalent
    while (!HIB_CTL_WRC_bit);
    HIB_IM = 0x01;                                   // Set interrupt mask
    while (!HIB_CTL_WRC_bit);
    HIB_CTL = 0x41;                                  // Turn on counter
}

#endif

// ============================================================================
//                                                                        USB
// ============================================================================

#if ( _MMB_MODULE_USB == 1 )

//  Enables power for USB device.

static sbit BSP_USB_PSW at                          GPIO_PORTD_AHB_DATA.B6;

//static sbit BSP_USB_PSW at                          GPIO_PORTD_AHB_DATA6_bit;

static void hal_usb_init ( void )
{
    //  Enable alternate GPIO function if needed

    GPIO_Config( &GPIO_PORTB_AHB, _GPIO_PINMASK_0 | _GPIO_PINMASK_1, _GPIO_DIR_INPUT, _GPIO_CFG_ADV_AIN | _GPIO_CFG_DRIVE_2mA, 0 );
    GPIO_Config( &GPIO_PORTL,     _GPIO_PINMASK_6 | _GPIO_PINMASK_7, _GPIO_DIR_INPUT, _GPIO_CFG_ADV_AIN | _GPIO_CFG_DRIVE_2mA, 0 );
    
    GPIO_PORTL_AMSEL = 0xC0;

    //  Initialize PWS pin as output.

    GPIO_Digital_Output( &GPIO_PORTD_AHB_DATA, _GPIO_PINMASK_6 );

    // PSW to 0 to turn on power for device.

    BSP_USB_PSW = 1;
    Delay_ms(100);
    BSP_USB_PSW = 0;
}

#endif

// ============================================================================
//                                                                    SHUTTLE
// ============================================================================

#if ( _MMB_MODULE_SHUTTLE == 1 )



#endif
#endif

/* -------------------------------------------------------------------------- */
/*
    mmb_mcu_---.h

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */